module Pages.Contact exposing (Model, Msg, page)

import Config.Colour as T exposing (..)
import Config.Format as O exposing (..)
import Config.Identity as I exposing (..)
import Config.Response exposing (..)
import Config.Viewport exposing (..)
import Contact.Helpers exposing (..)
import Contact.Methods.Discord exposing (contactDiscord)
import Contact.Methods.Email exposing (contactEmail)
import Effect exposing (Effect)
import Element exposing (..)
import Element.Font as F
import Headers.Helpers exposing (..)
import Headers.Pages.Contact exposing (contactHeader)
import Html
import Html.Attributes as H exposing (style)
import Layouts
import Page exposing (Page)
import Route exposing (Route)
import Shared exposing (..)
import View exposing (View)


page : Shared.Model -> Route () -> Page Model Msg
page shared route =
    Page.new
        { init = init
        , update = update
        , subscriptions = subscriptions
        , view = view shared
        }
        |> Page.withLayout toLayout


toLayout : Model -> Layouts.Layout Msg
toLayout model =
    Layouts.Navbar {  }



-- INIT


type alias Model =
    {}


init : () -> ( Model, Effect Msg )
init () =
    ( {}
    , Effect.map
        (\_ -> NoOp)
        (Effect.sendCmd resetViewport)
    )



-- UPDATE


type Msg
    = NoOp


update : Msg -> Model -> ( Model, Effect Msg )
update msg model =
    case msg of
        NoOp ->
            ( model
            , Effect.none
            )



-- SUBSCRIPTIONS


subscriptions : Model -> Sub Msg
subscriptions model =
    Sub.none



-- VIEW


view : Shared.Model -> Model -> View Msg
view shared model =
    { title = contactName
    , attributes = []
    , element = contactContainer shared.device
    }


contactContainer : Device -> Element msg
contactContainer device =
    topLevelContainer (contactList device)


contactList : Device -> Element msg
contactList device =
    column pageListDesktop <|
        List.concat
            (case ( device.class, device.orientation ) of
                ( Phone, Portrait ) ->
                    [ [ instructionMaker ] ]

                ( Phone, Landscape ) ->
                    [ [ instructionMaker ] ]

                ( Tablet, Portrait ) ->
                    [ [ instructionMaker ] ]

                ( Tablet, Landscape ) ->
                    [ [ instructionMaker ] ]

                ( Desktop, Portrait ) ->
                    [ [ instructionMaker ] ]

                ( Desktop, Landscape ) ->
                    [ [ instructionMaker ] ]

                ( BigDesktop, Portrait ) ->
                    [ [ instructionMaker ] ]

                ( BigDesktop, Landscape ) ->
                    [ [ instructionMaker ] ]
            )
